@@ -205,8 +205,11 @@ void memcache_socket::cmd_bin(const memcache::binary_request& cmd) {
                 add_lock(k);
             }
             if( obj.expired() ) return false;
-            if( cmd.exptime() != mc::binary_request::EXPTIME_NONE )
+            if( cmd.exptime() != mc::binary_request::EXPTIME_NONE ) {
                 obj.touch( cmd.exptime() );
+                if( ! m_slaves.empty() )
+                    repl_touch(m_slaves, k, obj);
+            }
             cybozu::dynbuf buf(0);
             const cybozu::dynbuf& data = obj.data(buf);
             if( cmd.command() == binary_command::Get ||
@@ -295,7 +298,7 @@ void memcache_socket::cmd_bin(const memcache::binary_request& cmd) {
                     r.set( o.cas_unique() );
                 if( ! m_slaves.empty() )
                     repl_object(m_slaves, k, o);
-                return std::move(o);
+                return o;
             };
         }
         if( ! m_hash.apply(cybozu::hash_key(p, len), h, c) ) {
@@ -451,7 +454,7 @@ void memcache_socket::cmd_bin(const memcache::binary_request& cmd) {
                     r.incdec( cmd.initial(), o.cas_unique() );
                 if( ! m_slaves.empty() )
                     repl_object(m_slaves, k, o);
-                return std::move(o);
+                return o;
             };
         }
         if( ! m_hash.apply(cybozu::hash_key(p, len), h, c) )
@@ -489,7 +492,7 @@ void memcache_socket::cmd_bin(const memcache::binary_request& cmd) {
                     r.incdec( cmd.initial(), o.cas_unique() );
                 if( ! m_slaves.empty() )
                     repl_object(m_slaves, k, o);
-                return std::move(o);
+                return o;
             };
         }
         if( ! m_hash.apply(cybozu::hash_key(p, len), h, c) )
@@ -501,7 +504,7 @@ void memcache_socket::cmd_bin(const memcache::binary_request& cmd) {
             if( obj.expired() ) return false;
             obj.touch( cmd.exptime() );
             if( ! m_slaves.empty() )
-                repl_object(m_slaves, k, obj, false);
+                repl_touch(m_slaves, k, obj);
             r.set( obj.cas_unique() );
             return true;
         };
@@ -665,7 +668,7 @@ void memcache_socket::cmd_text(const memcache::text_request& cmd) {
                     r.stored();
                 if( ! m_slaves.empty() )
                     repl_object(m_slaves, k, o);
-                return std::move(o);
+                return o;
             };
         }
         if( ! m_hash.apply(cybozu::hash_key(p, len), h, c) && ! cmd.no_reply() )
@@ -809,7 +812,7 @@ void memcache_socket::cmd_text(const memcache::text_request& cmd) {
             if( obj.expired() ) return false;
             obj.touch( cmd.exptime() );
             if( ! m_slaves.empty() )
-                repl_object(m_slaves, k, obj, false);
+                repl_touch(m_slaves, k, obj);
             return true;
         };
         if( m_hash.apply(cybozu::hash_key(p, len), h, c) ) {
